@@ -1,4 +1,7 @@
-github_api_issue_create = function(repo, title, body, labels, assignees){
+github_api_issue_create = function(repo, title, body, labels=character(), assignees=character()){
+  arg_is_chr_scalar(repo, title, body)
+  arg_is_chr(labels, assignees)
+
   ghclass_api_v3_req(
     endpoint = "POST /repos/:owner/:repo/issues",
     owner = get_repo_owner(repo),
@@ -12,9 +15,12 @@ github_api_issue_create = function(repo, title, body, labels, assignees){
 
 
 #' @rdname issue
+#'
+#' @param delay Numeric. Delay between each API request. Issue creation has a secondary rate limit (~ 20/min).
+#'
 #' @export
 #'
-issue_create = function(repo, title, body, labels = character(), assignees = character()) {
+issue_create = function(repo, title, body, labels = character(), assignees = character(), delay=0) {
 
   arg_is_chr(repo, title, body)
 
@@ -24,8 +30,24 @@ issue_create = function(repo, title, body, labels = character(), assignees = cha
   if (!is.list(assignees))
     assignees = list(assignees)
 
+  # Handle any necessary recycling
+  df = tibble::tibble(
+    repo, title, body, labels, assignees
+  )
+
+  n = nrow(df)
+
+  if (n > 20 & delay == 0) {
+    cli::cli_alert_info(c(
+      "Attempting to create {.val {n}} issues - this is likely to trigger GitHub's secondary rate limit.",
+      "Setting a delay of 5 seconds per request to avoid this, override this using {.field delay}."
+    ), wrap=TRUE)
+
+    delay = 5
+  }
+
   res = purrr::pmap(
-    list(repo, title, body, labels, assignees),
+    df,
     function(repo, title, body, labels, assignees) {
       res = purrr::safely(github_api_issue_create)(
         repo, title, body, labels, assignees
@@ -37,6 +59,8 @@ issue_create = function(repo, title, body, labels = character(), assignees = cha
         "Failed to create issue {.val {title}} for repo {.val {repo}}."
       )
 
+      Sys.sleep(delay)
+
       res
     }
   )
